# Generated by roxygen2: do not edit by hand

S3method(assumptions,dfr_dist)
S3method(cdf,dfr_dist)
S3method(cum_haz,dfr_dist)
S3method(density,dfr_dist)
S3method(fit,dfr_dist)
S3method(hazard,dfr_dist)
S3method(hess_loglik,dfr_dist)
S3method(inv_cdf,dfr_dist)
S3method(loglik,dfr_dist)
S3method(params,dfr_dist)
S3method(plot,dfr_dist)
S3method(print,dfr_dist)
S3method(residuals,dfr_dist)
S3method(sampler,dfr_dist)
S3method(score,dfr_dist)
S3method(sup,dfr_dist)
S3method(surv,dfr_dist)
export(assumptions)
export(cdf)
export(cum_haz)
export(dfr_dist)
export(dfr_exponential)
export(dfr_gompertz)
export(dfr_loglogistic)
export(dfr_weibull)
export(fit)
export(hazard)
export(hess_loglik)
export(inv_cdf)
export(is_dfr_dist)
export(is_likelihood_model)
export(loglik)
export(params)
export(qqplot_residuals)
export(sampler)
export(score)
export(sup)
export(surv)
importFrom(algebraic.dist,cdf)
importFrom(algebraic.dist,hazard)
importFrom(algebraic.dist,interval)
importFrom(algebraic.dist,inv_cdf)
importFrom(algebraic.dist,params)
importFrom(algebraic.dist,sampler)
importFrom(algebraic.dist,sup)
importFrom(algebraic.dist,surv)
importFrom(generics,fit)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(likelihood.model,assumptions)
importFrom(likelihood.model,hess_loglik)
importFrom(likelihood.model,is_likelihood_model)
importFrom(likelihood.model,loglik)
importFrom(likelihood.model,score)
importFrom(stats,density)
importFrom(stats,integrate)
importFrom(stats,optim)
importFrom(stats,ppoints)
importFrom(stats,qexp)
importFrom(stats,qqplot)
importFrom(stats,residuals)
importFrom(stats,runif)
importFrom(stats,uniroot)
importFrom(utils,modifyList)
