# Re-exports from likelihood.model
#' @importFrom likelihood.model loglik
#' @export
likelihood.model::loglik

#' @importFrom likelihood.model score
#' @export
likelihood.model::score

#' @importFrom likelihood.model hess_loglik
#' @export
likelihood.model::hess_loglik

#' @importFrom likelihood.model is_likelihood_model
#' @export
likelihood.model::is_likelihood_model

#' @importFrom likelihood.model assumptions
#' @export
likelihood.model::assumptions

# Re-export from generics
#' @importFrom generics fit
#' @export
generics::fit

# Re-exports from algebraic.dist
#' @importFrom algebraic.dist hazard
#' @export
algebraic.dist::hazard

#' @importFrom algebraic.dist surv
#' @export
algebraic.dist::surv

#' @importFrom algebraic.dist cdf
#' @export
algebraic.dist::cdf

#' @importFrom algebraic.dist inv_cdf
#' @export
algebraic.dist::inv_cdf

#' @importFrom algebraic.dist sampler
#' @export
algebraic.dist::sampler

#' @importFrom algebraic.dist params
#' @export
algebraic.dist::params

#' @importFrom algebraic.dist sup
#' @export
algebraic.dist::sup
