% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{diagnostics}
\alias{diagnostics}
\title{Diagnostic Methods for DFR Distributions}
\description{
Methods for assessing model fit and visualizing survival distributions.
}
\concept{dfr_dist}
