% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{kaplan_meier}
\alias{kaplan_meier}
\title{Compute Kaplan-Meier and Nelson-Aalen Estimates}
\usage{
kaplan_meier(time, delta)
}
\arguments{
\item{time}{Observation times}

\item{delta}{Event indicators (1 = event, 0 = censored)}
}
\value{
List with time, surv, cumhaz
}
\description{
Internal function to compute non-parametric survival estimates.
}
\keyword{internal}
