% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dfr_dist.R
\name{hess_loglik.dfr_dist}
\alias{hess_loglik.dfr_dist}
\title{Hessian of log-likelihood for dfr_dist}
\usage{
\method{hess_loglik}{dfr_dist}(model, ...)
}
\arguments{
\item{model}{A dfr_dist object}

\item{...}{Additional arguments passed to loglik}
}
\value{
A function that computes the Hessian matrix
}
\description{
Returns a function that computes the Hessian matrix of the log-likelihood.
Uses user-provided Hessian function if available, otherwise falls back to
numerical differentiation via numDeriv::hessian.
}
